==> huaweicloudsdkmrs-3.0.82-py2.py3-none-any.whl: huaweicloudsdkmrs/v2/model/create_execute_job_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateExecuteJobResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'job_submit_result': 'JobSubmitResult'
    }

    attribute_map = {
        'job_submit_result': 'job_submit_result'
    }

    def __init__(self, job_submit_result=None):
        """CreateExecuteJobResponse - a model defined in huaweicloud sdk"""
        
        super(CreateExecuteJobResponse, self).__init__()

        self._job_submit_result = None
        self.discriminator = None

        if job_submit_result is not None:
            self.job_submit_result = job_submit_result

    @property
    def job_submit_result(self):
        """Gets the job_submit_result of this CreateExecuteJobResponse.


        :return: The job_submit_result of this CreateExecuteJobResponse.
        :rtype: JobSubmitResult
        """
        return self._job_submit_result

    @job_submit_result.setter
    def job_submit_result(self, job_submit_result):
        """Sets the job_submit_result of this CreateExecuteJobResponse.


        :param job_submit_result: The job_submit_result of this CreateExecuteJobResponse.
        :type: JobSubmitResult
        """
        self._job_submit_result = job_submit_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateExecuteJobResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmrs-3.0.100-py2.py3-none-any.whl: huaweicloudsdkmrs/v2/model/create_execute_job_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateExecuteJobResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'job_submit_result': 'JobSubmitResult'
    }

    attribute_map = {
        'job_submit_result': 'job_submit_result'
    }

    def __init__(self, job_submit_result=None):
        """CreateExecuteJobResponse

        The model defined in huaweicloud sdk

        :param job_submit_result: 
        :type job_submit_result: :class:`huaweicloudsdkmrs.v2.JobSubmitResult`
        """
        
        super(CreateExecuteJobResponse, self).__init__()

        self._job_submit_result = None
        self.discriminator = None

        if job_submit_result is not None:
            self.job_submit_result = job_submit_result

    @property
    def job_submit_result(self):
        """Gets the job_submit_result of this CreateExecuteJobResponse.


        :return: The job_submit_result of this CreateExecuteJobResponse.
        :rtype: :class:`huaweicloudsdkmrs.v2.JobSubmitResult`
        """
        return self._job_submit_result

    @job_submit_result.setter
    def job_submit_result(self, job_submit_result):
        """Sets the job_submit_result of this CreateExecuteJobResponse.


        :param job_submit_result: The job_submit_result of this CreateExecuteJobResponse.
        :type job_submit_result: :class:`huaweicloudsdkmrs.v2.JobSubmitResult`
        """
        self._job_submit_result = job_submit_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateExecuteJobResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
